# !usr/bin/env python
# coding=gbk
import matplotlib

matplotlib.use('Agg')
import pandas
import scipy.io.wavfile as wav
from pydub import AudioSegment
import subprocess
import os
from audioFeature import calcMFCC
SEP = os.sep

def wav2MFCC(dataset_dir='../data/test/dataset', datasetName='dataset'):
    for parent, dirnames, filenames in os.walk(dataset_dir):
        for filename in filenames:
            if '.DS_Store' not in filename and '.doc' not in filename:
                file_path = os.path.join(parent, filename)
                (rate, sig) = wav.read(file_path)
                mfcc_feat = calcMFCC(sig, rate)
                mfcc_feat_path = os.path.dirname(file_path) + SEP + os.path.basename(file_path).split('.')[0] + '.mfcc'
                mfcc_feat_path = mfcc_feat_path.replace(datasetName, datasetName + '_mfcc')
                if os.path.isdir(mfcc_feat_path):
                    pass
                else:
                    os.makedirs(os.path.dirname(mfcc_feat_path))
                pandas.to_pickle(mfcc_feat, mfcc_feat_path)
    return 0


def mp32Wav(path_to_process='../data/test/dataset', datasetName='dataset', sample_rate=16000):
    count = 0
    for parent, dirnames, filenames in os.walk(path_to_process):
        for filename in filenames:
            if '.mp3' in filename or '.MP3' in filename:
                file_path = os.path.join(parent, filename)
                rate = sample_rate
                count += 1

                print 'processing...NO.%d ' % count + file_path
                file_fromat = file_path[-3:]
                out_path = os.path.dirname(file_path) + SEP + os.path.basename(file_path).split('.')[0] + '.wav'
                out_path = out_path.replace(datasetName, 'mono_wav' + str(rate / 1000.0))
                sound = AudioSegment.from_file(file_path, file_fromat)
                new = sound.set_channels(1)
                new = new.set_frame_rate(rate)
                if not os.path.exists(os.path.dirname(out_path)):
                    os.makedirs(os.path.dirname(out_path))
                new.export(out_path, 'wav')
    return 0


def mpeg2wav(mvs_dir='MV'):
    # readme mv title should not have space like that "I Love pytho.mpeg" u can change space to _
    for parent, dirnames, filenames in os.walk(mvs_dir):
        for filename in filenames:
            mv_dir = os.path.join(parent, filename)

            audio_dir = 'audio/' + os.path.splitext(mv_dir)[0] + '.wav'
            if not os.path.exists(os.path.split(audio_dir)[0]):
                os.makedirs(os.path.split(audio_dir)[0])
            command = 'ffmpeg -i ' + mv_dir + ' -ab 160k -ac 2 -ar 44100 -vn ' + audio_dir
            subprocess.call(command, shell=True)

            mono_sound_dir = 'mono/' + audio_dir
            if not os.path.exists(os.path.split(mono_sound_dir)[0]):
                os.makedirs(os.path.split(mono_sound_dir)[0])
            left_audio_dir = 'left_right/' + os.path.splitext(mono_sound_dir)[0] + '_left.wav'
            if not os.path.exists(os.path.split(left_audio_dir)[0]):
                os.makedirs(os.path.split(left_audio_dir)[0])
            right_audio_dir = 'left_right/' + os.path.splitext(mono_sound_dir)[0] + '_right.wav'
            if not os.path.exists(os.path.split(right_audio_dir)[0]):
                os.makedirs(os.path.split(right_audio_dir)[0])
            sound = AudioSegment.from_wav(audio_dir)
            mono = sound.set_channels(1)
            left, right = sound.split_to_mono()
            mono.export(mono_sound_dir, format='wav')
            left.export(left_audio_dir, format='wav')
            right.export(right_audio_dir, format='wav')
    return 0



# !usr/bin/env python
# coding=gbk
import numpy as np
import os
import matplotlib
from scipy.io.wavfile import read, write
import pip
from subprocess import call

matplotlib.use('Agg')
import matplotlib.pyplot as plt

INFO = "author:ZHANG Xu-long\nemail:fudan0027zxl@gmail.com\nblog:zhangxulong.site\n"

SEP = os.sep
SHORT_MAX = 32767
EPSILON = 1e-8


def init_data_dir():
    currentPath = os.getcwd()
    projectName = currentPath.split(SEP)[-1]
    if_no_create_it('../data/' + projectName + '/')
    return '../data/' + projectName + '/'


def savefig(filename, figlist, log=True):
    h = 10
    n = len(figlist)
    # peek into instances
    f = figlist[0]
    if len(f.shape) == 1:
        plt.figure()
        for i, f in enumerate(figlist):
            plt.subplot(n, 1, i + 1)
            if len(f.shape) == 1:
                plt.plot(f)
                plt.xlim([0, len(f)])
    elif len(f.shape) == 2:
        Nsmp, dim = figlist[0].shape
        figsize = (h * float(Nsmp) / dim, len(figlist) * h)
        plt.figure(figsize=figsize)
        for i, f in enumerate(figlist):
            plt.subplot(n, 1, i + 1)
            if log:
                plt.imshow(np.log(f.T + EPSILON))
            else:
                plt.imshow(f.T + EPSILON)
    else:
        raise ValueError('Input dimension must < 3.')
    plt.savefig(filename)


def wavread(filename):
    fs, x = read(filename)
    x = x.astype(np.float) / SHORT_MAX
    return x, fs


def wavwrite(filename, fs, y):
    ymax = np.max(np.abs(y))
    if ymax < 1.0:
        y = y * SHORT_MAX
    else:
        y = (y / ymax) * SHORT_MAX
    y = y.astype(np.int16)
    write(filename, fs, y)


def print_to_check(print_list=['a', 'b']):
    for print_item in print_list:
        print(print_item)


def if_no_create_it(file_path):
    the_dir = os.path.dirname(file_path)
    if os.path.isdir(the_dir):
        pass
    else:
        os.makedirs(the_dir)


def del_the_file(file_path):
    os.remove(file_path)


def update_pip_install_packages():
    for dist in pip.get_installed_distributions():
        call("sudo pip install --upgrade " + dist.project_name, shell=True)
    return 0



from .baseZhang import *
from .recordAudio import recordAudio
from .audioFeature import calcMFCC, calcMFCC_delta, calcMFCC_delta_delta, fbank, log_fbank, log_spectrum_power
from .countDays import countDaysBettweenTwo
from .formatTrans import *
from .modifyMarkdown import *
from .plotVisualData import plot_waveform,plotDuralWav,plotmono_waveform,plotstereo_waveform,plotstft,plotMonoWav,plotssd,plotmatrix
from .videoProcess import videoProcess
from .youtubeDownload import *
from .split2word import split_into_words



# !usr/bin/env python
# coding=utf-8
import os
import tkFileDialog
import wave
from Tkconstants import LEFT
from datetime import datetime
from Tkinter import Button, Label, mainloop, Frame, Entry, StringVar, Tk
from pyaudio import PyAudio, paInt16


class Record:
    def __init__(self):
        # define of params
        self.NUM_SAMPLES = 2000
        self.framerate = 16000
        self.channels = 1
        self.sampwidth = 2
        # record time
        self.TIME = 10

        root = Tk()
        root.resizable(False, False)
        self.center_window(root, 300, 110)
        chose_file_path_frm = Frame(root)
        chose_file_path_top_frm = Frame(chose_file_path_frm)
        labe_choose_path = Label(chose_file_path_top_frm, text="chose a path:        ")
        labe_choose_path.pack()
        chose_file_path_top_frm.pack()
        chose_file_path_down_frm = Frame(chose_file_path_frm)
        path_entry = Entry(chose_file_path_down_frm)
        self.contend_path_entry = StringVar()
        self.contend_path_entry.set('record/zhangxulong')
        path_entry.config(textvariable=self.contend_path_entry, state='disabled', highlightbackground='red')
        path_entry.pack(side=LEFT)
        file_chose_button = Button(chose_file_path_down_frm, text='chose', command=self.chose_file_path)
        file_chose_button.pack(side=LEFT)

        chose_file_path_down_frm.pack()
        set_a_file_name_for_record_frm = Frame(chose_file_path_frm)

        set_a_file_name_for_record_top_frm = Frame(set_a_file_name_for_record_frm)
        labe_file_nam = Label(set_a_file_name_for_record_frm, text="set a file name:        ")
        labe_file_nam.pack()
        set_a_file_name_for_record_top_frm.pack()

        name_entry_frm = Frame(set_a_file_name_for_record_frm)

        name_entry = Entry(name_entry_frm)
        self.contend_name_entry = StringVar()
        self.contend_name_entry.set(datetime.now().strftime("%Y-%m-%d_%H_%M_%S"))
        name_entry.config(textvariable=self.contend_name_entry)
        name_entry.pack(side=LEFT)
        start_button = Button(name_entry_frm, text='record', command=self.record_wave)
        start_button.pack(side=LEFT)
        name_entry_frm.pack()
        set_a_file_name_for_record_frm.pack()
        chose_file_path_frm.pack()

    def chose_file_path(self):

        files = tkFileDialog.askdirectory()
        self.contend_path_entry.set(files)

        return 0

    def save_wave_file(self, filename, data):
        '''save the date to the wav file'''
        wf = wave.open(filename, 'wb')
        wf.setnchannels(self.channels)
        wf.setsampwidth(self.sampwidth)
        wf.setframerate(self.framerate)
        wf.writeframes("".join(data))
        wf.close()
        return 0

    def file_path(self, FILE_PATH='/home/2'):
        if os.path.isdir(FILE_PATH):
            print 'dir %s exists' % (FILE_PATH)
            pass
        else:
            print  'dir %s not exists' % (FILE_PATH)
            os.makedirs(FILE_PATH)
        return 0

    def record_wave(self):
        wav_path = self.contend_path_entry.get()
        wav_name = self.contend_name_entry.get()
        if wav_path == "" or wav_name == "":
            filename = datetime.now().strftime("%Y-%m-%d_%H_%M_%S") + ".wav"
        else:
            self.file_path(wav_path)
            filename = wav_path + "/" + wav_name + ".wav"
        # open the input of wave
        pa = PyAudio()
        stream = pa.open(format=paInt16, channels=1,
                         rate=self.framerate, input=True,
                         frames_per_buffer=self.NUM_SAMPLES)
        save_buffer = []
        count = 0
        while count < self.TIME * 4:
            # read NUM_SAMPLES sampling data
            string_audio_data = stream.read(self.NUM_SAMPLES)
            save_buffer.append(string_audio_data)
            count += 1
            print '.'

        self.save_wave_file(filename, save_buffer)
        save_buffer = []
        print filename, "saved"
        self.contend_name_entry.set("☆☆☆☆ saved at: " + filename)
        return 0

    def center_window(self, root, width, height):
        screenwidth = root.winfo_screenwidth()
        screenheight = root.winfo_screenheight()
        size = '%dx%d+%d+%d' % (width, height, (screenwidth - width) / 2, (screenheight - height) / 2)
        print(size)
        root.geometry(size)
        return 0


def recordAudio():
    Record()
    mainloop()



# -*- coding: utf-8 -*-
import os
import random
import time
from Tkinter import *

reload(sys)
sys.setdefaultencoding('utf8')
flag = True
win=False

def file_path(FILE_PATH='/home/wuxy/aaa111/22222'):
    if os.path.isdir(FILE_PATH):
        print 'dir %s exists' % (FILE_PATH)
        pass
    else:
        print  'dir %s not exists' % (FILE_PATH)
        os.makedirs(FILE_PATH)
    return 0

class Application(Frame):
    def get_input_title(self, path):
        file = os.path.basename(path)
        file_name = os.path.splitext(file)[0]
        return file_name

    def get_input_format(self, path):
        format = os.path.basename(path).split('.')[-1]
        return format

    def combine_all_video(self, dir="combine"):
        global original_name, path, output_format
        video = []
        video_path = []
        del_true = 0  # 0删除split 1 留下split
        for parent, dirname, filename in os.walk(dir):
            for file in filename:
                print file
                path = os.path.join(parent, file)
                print path
                input_format = self.get_input_format(path)
                output_format = input_format
                if input_format == "mp4" or input_format == 'MP4':
                    original_name = self.get_input_title(path)
                    video_path.append(path)
                else:
                    print "not mp4 file"
        video_path = sorted(video_path)
        for video_path_item in video_path:
            temp_title = "temp" + str(random.randint(1, 100000))
            temp_path = os.path.dirname(video_path_item) + "/" + temp_title + "." + output_format
            os.rename(video_path_item, temp_path)
            video.append(temp_path)
        if len(video) != 0:
            input_title = self.get_input_title(video[0])
            input_format = self.get_input_format(video[0])
            output = input_title
            output_format = input_format
            number = 1
            for sub_video in video:
                cmd_line = "ffmpeg -i " + sub_video + " -vcodec copy -acodec copy -vbsf h264_mp4toannexb temp/" + output + "_" + str(
                    number) + ".ts"
                os.system(cmd_line)
                if del_true == 0:
                    os.remove(sub_video)
                number += 1
            file_str = ""
            for file_i in range(len(video) - 1):
                file_str += "temp/" + output + "_" + str(file_i + 1) + ".ts|"
            file_str += "temp/" + output + "_" + str(len(video)) + ".ts"
            cmd_line = "ffmpeg -i \"concat:" + file_str + "\"  -vcodec copy -acodec copy -absf aac_adtstoasc out/" + output + "." + output_format
            print(cmd_line)
            os.system(cmd_line)
            for temp_i in range(len(video)):
                os.remove("temp/" + output + "_" + str(temp_i + 1) + ".ts")
            output_path = "out/" + output + "." + output_format
            ori_path = os.path.dirname(output_path) + "/" + original_name + u"合并." + output_format
            os.rename(output_path, ori_path)
            print(u'合并完毕前往out查看')
        else:
            print u"combine 空"
        return 0

    def split_video_for_1_mask(self, input_path='download/20150115.mp4', start='00:00:20', end="00:01:00"):  # 第一段视频
        input_title = self.get_input_title(input_path)
        output_title = input_title
        print output_title
        input_format = self.get_input_format(input_path)
        output_format = input_format
        cmd_line = "ffmpeg -ss " + start + " -t " + end + " -i " + input_path + " -vcodec copy -acodec copy -y " + "temp/" + output_title + "." + output_format
        print(cmd_line)
        os.system(cmd_line)
        return 0

    def split_video_for_2_1_combine(self, input_path='download/20150115.mp4', start='00:01:00'):  # 第二段视频
        end = '00:16:00'
        input_title = self.get_input_title(input_path)
        output_title = input_title
        input_format = self.get_input_format(input_path)
        output_format = input_format
        cmd_line = "ffmpeg -ss " + start + " -t " + end + "  -i " + input_path + " -vcodec copy -acodec copy -y " + "temp/combine_" + output_title + "_2." + output_format
        print(cmd_line)
        os.system(cmd_line)
        return 0

    def split_video_for_2_2_combine(self, input_path='download/20150115.mp4',
                                    start='00:18:00'):  # 第三段视频##############################广告后重叠部分控制00:08:00
        input_title = self.get_input_title(input_path)
        output_title = input_title
        input_format = self.get_input_format(input_path)
        output_format = input_format
        cmd_line = "ffmpeg -ss " + start + "  -i " + input_path + " -vcodec copy -acodec copy -y " + "temp/combine_" + output_title + "_3." + output_format
        print(cmd_line)
        os.system(cmd_line)
        return 0

    def just_2_mask(self, video_path='temp/mask_1.mp4'):  # 对第一段40秒视频加水印
        input_title = self.get_input_title(video_path)
        output_title = input_title
        input_format = self.get_input_format(video_path)
        output_format = input_format
        cmd_line = "ffmpeg -y -t 40 -i " + video_path + " -i temp/watermark.png -i temp/daleloogn.png -filter_complex \"overlay=x=if(lt(mod(t\,20)\,10)\,W-w-10\,NAN ):y=H-h-10,overlay=x=if(gt(mod(t\,20)\,10)\,W-w-10\,NAN ) :y=H-h-10\" -strict -2 temp/combine_" + output_title + "_1." + output_format
        print(cmd_line)
        os.system(cmd_line)
        return 0

    def combine_4b_video(self, video0='temp/720.mp4', video1='temp/combine_1.mp4', video2='temp/combine_2.mp4',
                         video3='temp/combine_3.mp4'):
        input_title = self.get_input_title(video1)
        output_title = input_title.split("_")[0]
        input_format = self.get_input_format(video1)
        output_format = input_format
        cmd_line = "ffmpeg -i " + video0 + " -vcodec copy -acodec copy -vbsf h264_mp4toannexb temp/ts" + output_title + "_0.ts"
        os.system(cmd_line)
        cmd_line = "ffmpeg -i " + video1 + " -vcodec copy -acodec copy -vbsf h264_mp4toannexb temp/ts" + output_title + "_1.ts"
        os.system(cmd_line)
        cmd_line = "ffmpeg -i " + video2 + " -vcodec copy -acodec copy -vbsf h264_mp4toannexb temp/ts" + output_title + "_2.ts"
        os.system(cmd_line)
        cmd_line = "ffmpeg -i " + video3 + " -vcodec copy -acodec copy -vbsf h264_mp4toannexb temp/ts" + output_title + "_3.ts"
        os.system(cmd_line)
        cmd_line = "ffmpeg -i \"concat:temp/ts" + output_title + "_0.ts|temp/ts" + output_title + "_1.ts|temp/ts" + output_title + "_2.ts|temp/ts" + output_title + "_3.ts\"  -vcodec copy -acodec copy -absf aac_adtstoasc out/out" + output_title + "_b." + output_format
        print(cmd_line)
        os.system(cmd_line)
        os.remove("temp/ts" + output_title + "_0.ts")
        os.remove("temp/ts" + output_title + "_1.ts")
        os.remove("temp/ts" + output_title + "_2.ts")
        os.remove("temp/ts" + output_title + "_3.ts")
        out = "out/out" + output_title + "_b." + output_format
        return out

    def detect_720_or_1080(self, video_path):
        cmd_line = "ffmpeg -i " + video_path + " 2>&1 | perl -lane \"print $1 if /([0-9]{2,}x[0-9]+)/\""
        print cmd_line
        print os.popen(cmd_line).readlines()
        size = os.popen(cmd_line).readlines()[0]
        return size

    def generatGIF(self, PATH='VIDEO——PATH', start_time="00:08:00"):  # 生成GIF封面图 时间为从00:22:20开始截取2秒钟
        # start_time = "00:00:40"  # 时间为从00:01:08开始
        dur_time = "8"  # 截取2秒钟
        random_title = str(random.randint(0, 1000))
        watermark_path = "temp/acfun.png"
        cmd_line = "ffmpeg -ss " + start_time + " -t " + dur_time + " -i " + PATH + " -r 1 -s 480*270 -vf \"movie=" + watermark_path + " [watermark]; [in][watermark] overlay=x=10:y=H-h-10 [out]\" -f gif out/" + random_title + ".gif"
        # cmd_line = "ffmpeg -ss " + start_time + " -t " + dur_time + " -i " + PATH + " -r 1 -s 480*270 -f gif out/" + random_title + ".gif"
        print cmd_line
        os.system(cmd_line)
        gif_path = "out/" + random_title + ".gif"
        return gif_path

    def batch_generatGIF(self, dir='out'):
        start_time = self.gifcontents.get()
        for parent, dirname, filename in os.walk(dir):
            for file in filename:
                print file
                path = os.path.join(parent, file)
                input_format = self.get_input_format(path)
                if (input_format == "mp4") and not ('nodelete' in path):
                    output_format = input_format
                    original_name = self.get_input_title(path)
                    temp_title = "temp" + str(random.randint(1, 10000))
                    temp_path = os.path.dirname(path) + "/" + temp_title + "." + output_format
                    os.rename(path, temp_path)
                    print path
                    print(temp_path)
                    gif_path = self.generatGIF(temp_path, start_time)
                    os.rename(temp_path, path)
                    gif_formal_path = "out/GIF" + original_name + ".gif"
                    os.rename(gif_path, gif_formal_path)
        print u"GIF封面图生成完毕，前往out文件夹查看"
        return 0



    def secs2str(self,secs):
        return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(secs))

    def get_total_time(self, temp_path):

        if win:
            cmd_line = "ffprobe -v error -select_streams v:0 -show_entries stream=duration -of default=noprint_wrappers=1:nokey=1 " + temp_path  # findstr(in win)
            print cmd_line
            duration=os.popen(cmd_line).readlines()
            duration=duration[0].split('\\')[0]
            print duration
            duration= self.secs2str(float(duration))[11:19]
        else:
            cmd_line = "ffmpeg -i " + temp_path + "  2>&1 | grep 'Duration' | cut -d ' ' -f 4 | sed s/,//"  # grep(in ubuntu)
            duration = os.popen(cmd_line).readlines()[0][0:8]
        return duration

    def get_time_list(self, duration, N):
        now_time="2016:06:06:"
        time_list = []
        start_time = "00:00:00"
        time_list.append(start_time)
        end_time = duration
        s_start_time = time.mktime(time.strptime(now_time+start_time, '%Y:%m:%d:%H:%M:%S'))
        s_end_time = time.mktime(time.strptime(now_time+end_time, '%Y:%m:%d:%H:%M:%S'))
        s_now= time.mktime(time.strptime("2016:06:06:00:00:00", '%Y:%m:%d:%H:%M:%S'))
        total_s = s_end_time - s_start_time
        segment_one = total_s / N
        for n_i in range(N - 1):
            end_segment = (n_i + 1) * segment_one + s_start_time
            print end_segment
            print "*****************"
            end_segment_time = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(end_segment))[-8:]
            print end_segment_time
            time_list.append(end_segment_time)
        time_list.append(end_time)
        print time_list
        print "$$$$$$$$$$$$$$$$$$$$$$$$$$$time_list*********************"
        return time_list

    def split_extract_video(self, input_path, start_time, end_time, segmentsNO):
        input_title = self.get_input_title(input_path)
        output_title = input_title
        output_format = self.get_input_format(input_path)
        cmd_line = "ffmpeg -ss " + str(start_time) + " -i " + input_path + \
                   " -vcodec copy -acodec copy " + " -t " + str(end_time) + " -y " + "out/" + output_title + "_" + str(
            segmentsNO) + "part." + output_format
        os.system(cmd_line)
        print cmd_line
        print "*****************((((((((((((((((((((((((((((())))))))))))))))))))))))))))"
        out = "out/" + output_title + "_" + str(segmentsNO) + "part." + output_format
        return out

    def split_n_video(self, input_dir='split'):  # 仅需修改此处分割时间即可 *****************
        N = self.contents.get()
        N = int(N)
        print N
        print('the N is : ', self.contents.get())
        for parent, dirname, filename in os.walk(input_dir):
            for file in filename:
                print file
                path = os.path.join(parent, file)
                input_format = self.get_input_format(path)
                output_format = input_format
                original_name = self.get_input_title(path)
                temp_title = "temp" + str(random.randint(1, 100000))
                temp_path = os.path.dirname(path) + "/" + temp_title + "." + output_format
                os.rename(path, temp_path)
                duration = self.get_total_time(temp_path)
                print N
                time_list = self.get_time_list(duration, N)
                for i_N in range(N):
                    print "debug*********************************************************88"
                    print N
                    print time_list[i_N]
                    out_path = self.split_extract_video(temp_path, time_list[i_N], time_list[1], i_N + 1)
                    ori_path = os.path.dirname(out_path) + "/" + original_name + str(i_N + 1) + "." + output_format
                    os.rename(out_path, ori_path)
                os.rename(temp_path, path)
        print u"视频分割完毕，到out文件夹查看"
        return 0

    def extract_video(self, input_dir='split'):  # 仅需修改此处分割时间即可 *****************
        start = self.contentsstart.get()
        end = self.contentsend.get()
        for parent, dirname, filename in os.walk(input_dir):
            for file in filename:
                print file
                path = os.path.join(parent, file)
                input_format = self.get_input_format(path)
                output_format = input_format
                original_name = self.get_input_title(path)
                temp_title = "temp" + str(random.randint(1, 100))
                temp_path = os.path.dirname(path) + "/" + temp_title + "." + output_format
                os.rename(path, temp_path)
                out_path = self.split_extract_video(temp_path, start, end, 101)
                ori_path = os.path.dirname(out_path) + "/" + original_name + str(101) + "." + output_format
                os.rename(out_path, ori_path)
                os.rename(temp_path, path)
        print u"视频提取完毕，到out文件夹查看"
        return 0

    def createWidgets(self):
        pass

    def generate_acfun(self, temp_path, size, ad_duration_seconds, ssy720contents_point, original_name):
        print (temp_path, size, ad_duration_seconds, ssy720contents_point)
        total_duration = self.get_total_time(temp_path)
        out1 = self.split_extract_video(temp_path, start_time='00:00:20', end_time=ssy720contents_point, segmentsNO=1)
        out2 = self.split_extract_video(temp_path, start_time=ssy720contents_point, end_time=total_duration,
                                        segmentsNO=2)
        print"8*******"
        print out1
        print out2
        if '1080' in size:
            middle_ad = 'temp/1080_' + ad_duration_seconds + '.mp4'
        else:
            middle_ad = 'temp/720_' + ad_duration_seconds + '.mp4'
        input_title = self.get_input_title(out1)
        output_title = input_title.split("_")[0]
        input_format = self.get_input_format(out1)
        output_format = input_format
        cmd_line = "ffmpeg -i " + out1 + " -vcodec copy -acodec copy -vbsf h264_mp4toannexb temp/ts" + output_title + "_0.ts"
        os.system(cmd_line)
        cmd_line = "ffmpeg -i " + middle_ad + " -vcodec copy -acodec copy -vbsf h264_mp4toannexb temp/ts" + output_title + "_1.ts"
        os.system(cmd_line)
        cmd_line = "ffmpeg -i " + out2 + " -vcodec copy -acodec copy -vbsf h264_mp4toannexb temp/ts" + output_title + "_2.ts"
        os.system(cmd_line)
        cmd_line = "ffmpeg -i \"concat:temp/ts" + output_title + "_0.ts|temp/ts" + output_title + "_1.ts|temp/ts" + output_title + "_2.ts\"  -vcodec copy -acodec copy -absf aac_adtstoasc out/out" + output_title + "_a." + output_format
        print(cmd_line)
        os.system(cmd_line)
        dest_path = "out/ORIGINAL" + original_name + '.mp4'
        os.rename(temp_path, dest_path)
        os.remove(out1)
        os.remove(out2)
        os.remove("temp/ts" + output_title + "_0.ts")
        os.remove("temp/ts" + output_title + "_1.ts")
        os.remove("temp/ts" + output_title + "_2.ts")
        temp_out_path = "out/out" + output_title + "_a." + output_format
        return temp_out_path

    def batch_mask(self, dir='out'):
        duration_seconds = self.duration_contents.get()
        print duration_seconds
        ssy720contents_point = self.ssy720contents_point.get()
        print ssy720contents_point
        for parent, dirname, filename in os.walk(dir):
            for file in filename:
                print file
                path = os.path.join(parent, file)
                input_format = self.get_input_format(path)
                output_format = input_format
                original_name = self.get_input_title(path)
                if (input_format == 'mp4' or input_format == 'MP4') and not ("nodelete" in path) and not (
                            "BAIDU" in original_name) and not (
                            "AcFun" in original_name) and not ("ORIGINAL" in original_name):
                    temp_title = "temp" + str(random.randint(1, 10000))
                    temp_path = os.path.dirname(path) + "/" + temp_title + "." + output_format
                    os.rename(path, temp_path)
                    print path
                    print(temp_path)
                    size = self.detect_720_or_1080(temp_path)
                    gif_path = self.generatGIF(temp_path)
                    gif_formal_path = "out/GIF" + original_name + ".gif"
                    os.rename(gif_path, gif_formal_path)
                    self.split_video_for_1_mask(temp_path)
                    self.split_video_for_2_1_combine(temp_path)
                    self.split_video_for_2_2_combine(temp_path)
                    temp_path = self.generate_acfun(temp_path, size, duration_seconds, ssy720contents_point,
                                                    original_name)
                    out_path = "out/AcFun" + original_name + "." + output_format
                    os.rename(temp_path, out_path)
                    file = temp_title + "." + output_format
                    self.just_2_mask('temp/' + file)
                    os.remove('temp/' + file)
                    if '1080' in size:
                        video0 = 'temp/1080.mp4'
                    else:
                        video0 = 'temp/720.mp4'
                    video1 = "temp/combine_" + file.split('.')[0] + "_1." + output_format
                    video2 = "temp/combine_" + file.split('.')[0] + "_2." + output_format
                    video3 = "temp/combine_" + file.split('.')[0] + "_3." + output_format
                    path = self.combine_4b_video(video0, video1, video2, video3)
                    ori_path = os.path.dirname(path) + "/BAIDU" + original_name + "." + output_format  # 含片头
                    os.rename(path, ori_path)
                    os.remove(video1)
                    os.remove(video2)
                    os.remove(video3)
                print u"水印制作完毕，前往out文件夹查看"
            else:
                print u"非加水印视频"
        else:
            print u"非加水印对象"
        return 0

    def __init__(self, master=None):
        self.frm = Frame.__init__(self, master)

        self.left = Frame(self.frm)
        self.left_top = Frame(self.left)
        self.left_top.pack(side=TOP)
        self.left_down = Frame(self.left)
        self.left_down.pack(side=TOP)
        self.left.pack(side=LEFT)

        self.right = Frame(self.frm)
        self.right_top = Frame(self.right)
        self.right_top.pack(side=TOP)
        self.right_down = Frame(self.right)
        self.right_down.pack(side=TOP)
        self.right.pack(side=RIGHT)

        self.doc_lable_combine = Label(self.left_top, text="注意：按a、b、c、d、e、f排序", fg="red")
        self.doc_lable_combine.pack(side=TOP)
        self.ssycom = Button(self.left_top)
        self.ssycom["text"] = "合并文件夹所有视频",
        self.ssycom["command"] = self.combine_all_video
        self.ssycom.pack(side=TOP)
        self.doc_lable_combine2 = Label(self.left_top, text="需合并的文件放置于【combine】文件夹", fg="red")
        self.doc_lable_combine2.pack(side=TOP)
        self.doc_seg1 = Label(self.left_top, text="-------------------------------", fg="blue")
        self.doc_seg1.pack(side=TOP)

        self.doc = Label(self.left_down, text="输入acfun片头长度5s或10s", fg="red")
        self.doc.pack(side=TOP)
        self.ssy720entrythingy = Entry(self.left_down)
        self.ssy720entrythingy.pack(side=TOP)
        self.duration_contents = StringVar()
        self.duration_contents.set("5s")
        self.ssy720entrythingy.config(textvariable=self.duration_contents)
        self.doc_point = Label(self.left_down, text="输入acfun片头插入位置", fg="red")
        self.doc_point.pack(side=TOP)
        self.ssy720entrythingy_point = Entry(self.left_down)
        self.ssy720entrythingy_point.pack(side=TOP)
        self.ssy720contents_point = StringVar()
        self.ssy720contents_point.set("00:20:20")
        self.ssy720entrythingy_point.config(textvariable=self.ssy720contents_point)
        self.ssy720 = Button(self.left_down)
        self.ssy720["text"] = "自动识别尺寸加水印",
        self.ssy720["command"] = self.batch_mask
        self.ssy720.pack(side=TOP)
        self.doc = Label(self.left_down, text="视频放置于【out】文件夹", fg="red")
        self.doc.pack(side=TOP)



        self.giflable_infoN = Label(self.right_top, text="输入开始生成时间点", fg="red")
        self.giflable_infoN.pack(side=TOP)
        self.gifentrythingy = Entry(self.right_top)
        self.gifentrythingy.pack(side=TOP)
        self.gifbutton = Button(self.right_top, text="开始单独生成GIF",
                                command=self.batch_generatGIF)
        self.gifbutton.pack(side=TOP)
        self.gifcontents = StringVar()
        self.gifcontents.set("00:06:08")
        self.gifentrythingy.config(textvariable=self.gifcontents)
        self.doc_lable_gif2 = Label(self.right_top, text="视频放置于【out】文件夹", fg="red")
        self.doc_lable_gif2.pack(side=TOP)
        self.doc_lable_seg3 = Label(self.right_top, text="----------------------------------------", fg="blue")
        self.doc_lable_seg3.pack(side=TOP)




        # self.doc_lable_split = Label(self.right_top, text="视频放置于【split】文件夹", fg="red")
        # self.doc_lable_split.pack(side=TOP)
        # self.lable_infoN = Label(self.right_top, text="输入等分割段数N进行分割", fg="red")
        # self.lable_infoN.pack(side=TOP)
        # self.entrythingy = Entry(self.right_top)
        # self.entrythingy.pack(side=TOP)
        # self.button = Button(self.right_top, text="1.开始N等分",
        #                      command=self.split_n_video)
        # self.button.pack(side=TOP)
        # self.contents = StringVar()
        # self.contents.set("2")
        # self.entrythingy.config(textvariable=self.contents)
        # self.doc_lable_seg4 = Label(self.right_top, text="----------------------************--------------------",
        #                             fg="green")
        # self.doc_lable_seg4.pack(side=TOP)

        self.lable_info = Label(self.right_down, text="输入起始时间如00:06:08", fg="red")
        self.lable_info.pack(side=TOP)
        self.entrystart = Entry(self.right_down)
        self.entrystart.pack(side=TOP)
        self.contentsstart = StringVar()
        self.contentsstart.set("00:06:08")
        self.entrystart.config(textvariable=self.contentsstart)
        self.lable_info2 = Label(self.right_down, text="输入持续时间00:10:00", fg="red")
        self.lable_info2.pack(side=TOP)
        self.entryend = Entry(self.right_down)
        self.entryend.pack(side=TOP)
        self.contentsend = StringVar()
        self.contentsend.set("00:10:00")
        self.entryend.config(textvariable=self.contentsend)
        self.buttonstart = Button(self.right_down, text="开始提取片段", command=self.extract_video)
        self.buttonstart.pack(side=TOP)
        self.doc_lable_split = Label(self.right_down, text="视频放置于【split】文件夹 ", fg="red")
        self.doc_lable_split.pack(side=TOP)
        # self.doc_lable_seg5 = Label(self.right_down, text="--------------------------------------------------------",
        #                             fg="green")
        # self.doc_lable_seg5.pack(side=TOP)

def videoProcess():
    file_path('combine')
    file_path('out/nodelete')
    file_path('split')
    file_path('out')
    file_path('temp')
    root = Tk()
    root.title("视频简易处理")
    app = Application(master=root)
    app.mainloop()
    return 0



# !usr/bin/env python
# coding=gbk
from subprocess import call
import pyPdf
from tqdm import tqdm
import os


def pdf_link_2_txt(path_pdf='drm20150330-20170310.pdf'):
    PDFFile = open(path_pdf, 'rb')

    PDF = pyPdf.PdfFileReader(PDFFile)
    pages = PDF.getNumPages()
    key = '/Annots'
    uri = '/URI'
    ank = '/A'
    all_link = []
    for page in range(pages):

        pageSliced = PDF.getPage(page)
        pageObject = pageSliced.getObject()

        if pageObject.has_key(key):
            ann = pageObject[key]
            for a in ann:
                u = a.getObject()
                if u[ank].has_key(uri):
                    print u[ank][uri]
                    if 'maomaoChyan' not in u[ank][uri]:
                        if 'channel' not in u[ank][uri]:
                            all_link.append(u[ank][uri])
    print len(all_link)
    print all_link
    print all_link[1]
    out_path = path_pdf.replace('.pdf', '.txt')
    file_txt = open(out_path, 'w')
    for link in all_link:
        file_txt.writelines(link)
        file_txt.writelines('\n')
    file_txt.close()
    return out_path


def download_youtube(link_txt='linkdrm20130701-20150325.txt'):
    txt_file = open(link_txt, 'r')
    links = txt_file.readlines()
    txt_file.close()
    for download_link in tqdm(links):
        # print links
        command = "youtube-dl " + download_link.split('&')[0] + " -c"
        print command
        call(command.split(), shell=False)

    # command = "youtube-dl https://www.youtube.com/watch?v=NG3WygJmiVs -c"
    # call(command.split(), shell=False)
    return 0


def rename_tag(rename_file_dir='toberename', tag='[пн]'):
    for parent, dirnames, filenames in os.walk(rename_file_dir):
        for filename in filenames:
            files_in = os.path.join(parent, filename)
            files_in_name = os.path.basename(files_in)
            files_out = files_in.replace(files_in_name, tag + files_in_name)
            os.rename(files_in, files_out)
    return 0



from distutils.core import setup

NAME = 'baseZhang'
_MAJOR = 1
_MINOR = 0
_MICRO = 5
VERSION = '%d.%d.%d' % (_MAJOR, _MINOR, _MICRO)
DOWNLOAD = "https://github.com/zhangxulong/baseZhang/dist/baseZhang-" + VERSION + ".tar.gz"
DESCRIPTION = "My own base util code"
setup(
    packages=['baseZhang'],
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description="""A python module for audio and music processing.""",
    author="ZHANG Xu-long",
    author_email="fudan0027zxl@gmail.com",
    license="BSD",
    url="http://zhangxulong.site",
    download_url=DOWNLOAD,
    keywords='audio music sound',
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "Topic :: Multimedia :: Sound/Audio :: Analysis",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",

    ],
    install_requires=['numpy', 'scipy', 'matplotlib', 'Cython', 'h5py', 'joblib', 'Keras', ' pandas', 'scikit-learn',
                      'tqdm', 'pydub'],
    zip_safe=False,
)



#!/usr/bin/python2

import pylab, numpy, scipy
from os import mkdir
from os.path import join as path_join
from math import floor, ceil
import scipy.io.wavfile as wf



def frame(x, fs, framesz, hop):
    framesamp = int(framesz * fs)
    hopsamp = int(hop * fs)
    w = scipy.hamming(framesamp)
    return scipy.array([w * x[i:i + framesamp]
                        for i in range(0, len(x) - framesamp, hopsamp)])


def stft(x, fs, framesz, hop):
    framesamp = int(framesz * fs)
    hopsamp = int(hop * fs)
    w = scipy.hamming(framesamp)
    X = scipy.array([scipy.fft(w * x[i:i + framesamp])
                     for i in range(0, len(x) - framesamp, hopsamp)])
    return X


def istft(X, fs, T, hop):
    x = scipy.zeros(T * fs)
    framesamp = X.shape[1]
    hopsamp = int(hop * fs)
    for n, i in enumerate(range(0, len(x) - framesamp, hopsamp)):
        x[i:i + framesamp] += scipy.real(scipy.ifft(X[n]))
    return x


def plot_selected(l, nst, ned, val=8e9):
    start_plot = scipy.zeros(l)
    end_plot = scipy.zeros(l)
    for a, b, n in zip(nst, ned, range(0, len(ned))):
        if n % 2 == 0:
            start_plot[a:b] = val * numpy.ones(b - a)
        else:
            end_plot[a:b] = val * numpy.ones(b - a)
    pylab.fill(start_plot, color="green")
    pylab.fill(end_plot, color="red")
    return 0


def signal_energy(signal, fs, fl=0.05, fh=0.02):
    X = stft(signal, fs, fl, fh)
    mag = scipy.absolute(X)
    energy = scipy.sum(mag, 1)
    return energy


def split_into_words(filename="singing5-w-fan.wav", wn=7,
                     thresh=13e6,
                     too_short=4):
    WORDS = [str(word) for word in range(wn)]
    (folder, ext) = filename.rsplit('.', 1)
    (fs, sig) = wf.read(filename)
    fl = 0.050
    fh = 0.020
    energy = signal_energy(sig, fs, fl, fh)
    xx = scipy.diff(scipy.r_[[0], (energy > thresh).astype(int)])
    yy = scipy.diff(scipy.r_[(energy > thresh).astype(int), [0]])
    start_sig = scipy.nonzero(xx > 0)[0]
    end_sig = scipy.nonzero(yy < 0)[0]
    nst = start_sig
    ned = end_sig
    dist = ned - nst
    tooshort = scipy.nonzero(dist < too_short)
    nst = scipy.delete(nst, tooshort)
    ned = scipy.delete(ned, tooshort)
    dist = ned - nst
    edist = ned[1:] - ned[:-1]
    ll = len(nst) - wn
    tor = edist.argsort()[:ll]
    nst = scipy.delete(nst, tor + 1)
    ned = scipy.delete(ned, tor)
    for a, b in zip(nst, ned):
        print(fs * fh * a), (fs * fh * b)

    words = scipy.array([sig[int(fs * fh * a):int(fs * fh * b)] for a, b in zip(nst, ned)])

    try:
        mkdir(folder)
        for w in WORDS:
            mkdir(path_join(folder, w))
    except OSError, ex:
        pass

    for w, n in zip(words, range(0, len(words))):
        ww = n % wn
        wwig = floor(float(n) / float(wn))
        flnm = path_join(folder, WORDS[ww], "%02d.wav" % (wwig + 1))
        wf.write(flnm, fs, w)
    pylab.figure()
    pylab.plot(energy)
    plot_selected(len(energy), nst, ned, thresh)
    pylab.show()
    return 0
split_into_words(filename="reading5-w-fan.wav", wn=7,
                     thresh=9e6,
                     too_short=6)


# !usr/bin/env python
# coding=gbk
def is_R_or_N(user_in_date=2017):  # 判断是否闰年
    # user_in_date = int(input('请输入四位数年份：'))
    # print user_in_date
    value_r_n = user_in_date % 4 == 0 and user_in_date % 100 != 0
    if value_r_n:
        result = str(user_in_date) + '是闰年'
        # print result
    else:
        result = str(user_in_date) + '不是闰年'
        # print result
    return value_r_n


def get_mEnd_days(mEnd=12, is_R_N=True):
    totaldays = 0
    if is_R_N:
        if mEnd == 12:
            totaldays = 30 + 31 + 30 + 31 + 31 + 30 + 31 + 30 + 31 + 29 + 31
        elif mEnd == 11:
            totaldays = 31 + 30 + 31 + 31 + 30 + 31 + 30 + 31 + 29 + 31
        elif mEnd == 10:
            totaldays = 30 + 31 + 31 + 30 + 31 + 30 + 31 + 29 + 31
        elif mEnd == 9:
            totaldays = 31 + 31 + 30 + 31 + 30 + 31 + 29 + 31
        elif mEnd == 8:
            totaldays = 31 + 30 + 31 + 30 + 31 + 29 + 31
        elif mEnd == 7:
            totaldays = 30 + 31 + 30 + 31 + 29 + 31
        elif mEnd == 6:
            totaldays = 31 + 30 + 31 + 29 + 31
        elif mEnd == 5:
            totaldays = 30 + 31 + 29 + 31
        elif mEnd == 4:
            totaldays = 31 + 29 + 31
        elif mEnd == 3:
            totaldays = 29 + 31
        elif mEnd == 2:
            totaldays = 31
        elif mEnd == 1:
            totaldays = 0
    else:
        if mEnd == 12:
            totaldays = 30 + 31 + 30 + 31 + 31 + 30 + 31 + 30 + 31 + 28 + 31
        elif mEnd == 11:
            totaldays = 31 + 30 + 31 + 31 + 30 + 31 + 30 + 31 + 28 + 31
        elif mEnd == 10:
            totaldays = 30 + 31 + 31 + 30 + 31 + 30 + 31 + 28 + 31
        elif mEnd == 9:
            totaldays = 31 + 31 + 30 + 31 + 30 + 31 + 28 + 31
        elif mEnd == 8:
            totaldays = 31 + 30 + 31 + 30 + 31 + 28 + 31
        elif mEnd == 7:
            totaldays = 30 + 31 + 30 + 31 + 28 + 31
        elif mEnd == 6:
            totaldays = 31 + 30 + 31 + 28 + 31
        elif mEnd == 5:
            totaldays = 30 + 31 + 28 + 31
        elif mEnd == 4:
            totaldays = 31 + 28 + 31
        elif mEnd == 3:
            totaldays = 28 + 31
        elif mEnd == 2:
            totaldays = 31
        elif mEnd == 1:
            totaldays = 0

    return totaldays


def get_year_toatal_days(year=2017):
    if is_R_or_N(year):
        total = 366
    else:
        total = 365
    return total


def get_yEnd_yStart_days(yEnd=2017, yStart=1949):
    totaday = 0
    years = range(yStart + 1, yEnd)
    for year_every in years:
        if is_R_or_N(year_every):
            totaday += 366
        else:
            totaday += 365
    return totaday


def countDaysBettweenTwo(dayStart='20150101', dayEnd='20170102'):
    yStart, mStart, dStart = int(dayStart[:4]), int(dayStart[4:6]), int(dayStart[6:8])
    yEnd, mEnd, dEnd = int(dayEnd[:4]), int(dayEnd[4:6]), int(dayEnd[6:8])
    print 'dayStart:', yStart, mStart, dStart
    print 'dayEnd:', yEnd, mEnd, dEnd

    dayPast = dEnd + get_mEnd_days(mEnd, is_R_or_N(yEnd))

    dayLeft = get_year_toatal_days(yStart) - dStart - get_mEnd_days(mStart, is_R_or_N(yStart))

    if yEnd - yStart == 1:
        FinalanswerDay = dayPast + dayLeft
    elif yEnd - yStart < 1:
        FinalanswerDay = dayPast - dStart - get_mEnd_days(mStart, is_R_or_N(yStart))
    else:
        FinalanswerDay = dayPast + dayLeft + get_yEnd_yStart_days(yEnd, yStart)
    return FinalanswerDay
